==> org.eclipse.incquery.uml.source_1.0.0.201504101636.jar: org/eclipse/incquery/uml/derivedfeatures/util/RedefinableTemplateSignatureInheritedParameterQuerySpecification.java <==
package org.eclipse.incquery.uml.derivedfeatures.util;

import com.google.common.collect.Sets;
import java.util.Arrays;
import java.util.List;
import java.util.Set;
import org.eclipse.incquery.runtime.api.IncQueryEngine;
import org.eclipse.incquery.runtime.api.impl.BaseGeneratedEMFPQuery;
import org.eclipse.incquery.runtime.api.impl.BaseGeneratedEMFQuerySpecification;
import org.eclipse.incquery.runtime.exception.IncQueryException;
import org.eclipse.incquery.runtime.matchers.psystem.PBody;
import org.eclipse.incquery.runtime.matchers.psystem.PVariable;
import org.eclipse.incquery.runtime.matchers.psystem.annotations.PAnnotation;
import org.eclipse.incquery.runtime.matchers.psystem.basicdeferred.Equality;
import org.eclipse.incquery.runtime.matchers.psystem.basicdeferred.ExportedParameter;
import org.eclipse.incquery.runtime.matchers.psystem.basicenumerables.TypeBinary;
import org.eclipse.incquery.runtime.matchers.psystem.basicenumerables.TypeUnary;
import org.eclipse.incquery.runtime.matchers.psystem.queries.PParameter;
import org.eclipse.incquery.runtime.matchers.psystem.queries.QueryInitializationException;
import org.eclipse.incquery.uml.derivedfeatures.RedefinableTemplateSignatureInheritedParameterMatch;
import org.eclipse.incquery.uml.derivedfeatures.RedefinableTemplateSignatureInheritedParameterMatcher;

/**
 * A pattern-specific query specification that can instantiate RedefinableTemplateSignatureInheritedParameterMatcher in a type-safe way.
 * 
 * @see RedefinableTemplateSignatureInheritedParameterMatcher
 * @see RedefinableTemplateSignatureInheritedParameterMatch
 * 
 */
@SuppressWarnings("all")
public final class RedefinableTemplateSignatureInheritedParameterQuerySpecification extends BaseGeneratedEMFQuerySpecification<RedefinableTemplateSignatureInheritedParameterMatcher> {
  private RedefinableTemplateSignatureInheritedParameterQuerySpecification() {
    super(GeneratedPQuery.INSTANCE);
  }
  
  /**
   * @return the singleton instance of the query specification
   * @throws IncQueryException if the pattern definition could not be loaded
   * 
   */
  public static RedefinableTemplateSignatureInheritedParameterQuerySpecification instance() throws IncQueryException {
    try{
    	return LazyHolder.INSTANCE;
    } catch (ExceptionInInitializerError err) {
    	throw processInitializerError(err);
    }
  }
  
  @Override
  protected RedefinableTemplateSignatureInheritedParameterMatcher instantiate(final IncQueryEngine engine) throws IncQueryException {
    return RedefinableTemplateSignatureInheritedParameterMatcher.on(engine);
  }
  
  @Override
  public RedefinableTemplateSignatureInheritedParameterMatch newEmptyMatch() {
    return RedefinableTemplateSignatureInheritedParameterMatch.newEmptyMatch();
  }
  
  @Override
  public RedefinableTemplateSignatureInheritedParameterMatch newMatch(final Object... parameters) {
    return RedefinableTemplateSignatureInheritedParameterMatch.newMatch((org.eclipse.uml2.uml.RedefinableTemplateSignature) parameters[0], (org.eclipse.uml2.uml.TemplateParameter) parameters[1]);
  }
  
  private static class LazyHolder {
    private final static RedefinableTemplateSignatureInheritedParameterQuerySpecification INSTANCE = make();
    
    public static RedefinableTemplateSignatureInheritedParameterQuerySpecification make() {
      return new RedefinableTemplateSignatureInheritedParameterQuerySpecification();					
    }
  }
  
  private static class GeneratedPQuery extends BaseGeneratedEMFPQuery {
    private final static RedefinableTemplateSignatureInheritedParameterQuerySpecification.GeneratedPQuery INSTANCE = new GeneratedPQuery();
    
    @Override
    public String getFullyQualifiedName() {
      return "org.eclipse.incquery.uml.derivedfeatures.redefinableTemplateSignatureInheritedParameter";
    }
    
    @Override
    public List<String> getParameterNames() {
      return Arrays.asList("source","target");
    }
    
    @Override
    public List<PParameter> getParameters() {
      return Arrays.asList(new PParameter("source", "org.eclipse.uml2.uml.RedefinableTemplateSignature"),new PParameter("target", "org.eclipse.uml2.uml.TemplateParameter"));
    }
    
    @Override
    public Set<PBody> doGetContainedBodies() throws QueryInitializationException {
      Set<PBody> bodies = Sets.newLinkedHashSet();
      try {
      {
      	PBody body = new PBody(this);
      	PVariable var_source = body.getOrCreateVariableByName("source");
      	PVariable var_target = body.getOrCreateVariableByName("target");
      	PVariable var__virtual_0_ = body.getOrCreateVariableByName(".virtual{0}");
      	PVariable var__virtual_1_ = body.getOrCreateVariableByName(".virtual{1}");
      	body.setExportedParameters(Arrays.<ExportedParameter>asList(
      		new ExportedParameter(body, var_source, "source"),
      				
      		new ExportedParameter(body, var_target, "target")
      	));
      	new TypeUnary(body, var_source, getClassifierLiteral("http://www.eclipse.org/uml2/5.0.0/UML", "RedefinableTemplateSignature"), "http://www.eclipse.org/uml2/5.0.0/UML/RedefinableTemplateSignature");
      	new TypeUnary(body, var_target, getClassifierLiteral("http://www.eclipse.org/uml2/5.0.0/UML", "TemplateParameter"), "http://www.eclipse.org/uml2/5.0.0/UML/TemplateParameter");
      	new TypeUnary(body, var_source, getClassifierLiteral("http://www.eclipse.org/uml2/5.0.0/UML", "RedefinableTemplateSignature"), "http://www.eclipse.org/uml2/5.0.0/UML/RedefinableTemplateSignature");
      	new TypeBinary(body, CONTEXT, var_source, var__virtual_0_, getFeatureLiteral("http://www.eclipse.org/uml2/5.0.0/UML", "RedefinableTemplateSignature", "extendedSignature"), "http://www.eclipse.org/uml2/5.0.0/UML/RedefinableTemplateSignature.extendedSignature");
      	new TypeBinary(body, CONTEXT, var__virtual_0_, var__virtual_1_, getFeatureLiteral("http://www.eclipse.org/uml2/5.0.0/UML", "TemplateSignature", "parameter"), "http://www.eclipse.org/uml2/5.0.0/UML/TemplateSignature.parameter");
      	new Equality(body, var__virtual_1_, var_target);
      	bodies.add(body);
      }
      	{
      	PAnnotation annotation = new PAnnotation("Surrogate");
      	annotation.addAttribute("feature", "inheritedParameter");
      	addAnnotation(annotation);
      }
      	// to silence compiler error
      	if (false) throw new IncQueryException("Never", "happens");
      } catch (IncQueryException ex) {
      	throw processDependencyException(ex);
      }
      return bodies;
    }
  }
}

==> org.eclipse.incquery.uml.source_1.0.0.201504211455.jar: org/eclipse/incquery/uml/derivedfeatures/util/RedefinableTemplateSignatureInheritedParameterQuerySpecification.java <==
package org.eclipse.incquery.uml.derivedfeatures.util;

import com.google.common.collect.Sets;
import java.util.Arrays;
import java.util.List;
import java.util.Set;
import org.eclipse.emf.ecore.EClass;
import org.eclipse.incquery.runtime.api.IncQueryEngine;
import org.eclipse.incquery.runtime.api.impl.BaseGeneratedEMFPQuery;
import org.eclipse.incquery.runtime.api.impl.BaseGeneratedEMFQuerySpecification;
import org.eclipse.incquery.runtime.emf.types.EClassTransitiveInstancesKey;
import org.eclipse.incquery.runtime.emf.types.EStructuralFeatureInstancesKey;
import org.eclipse.incquery.runtime.exception.IncQueryException;
import org.eclipse.incquery.runtime.matchers.psystem.PBody;
import org.eclipse.incquery.runtime.matchers.psystem.PVariable;
import org.eclipse.incquery.runtime.matchers.psystem.annotations.PAnnotation;
import org.eclipse.incquery.runtime.matchers.psystem.basicdeferred.Equality;
import org.eclipse.incquery.runtime.matchers.psystem.basicdeferred.ExportedParameter;
import org.eclipse.incquery.runtime.matchers.psystem.basicenumerables.TypeConstraint;
import org.eclipse.incquery.runtime.matchers.psystem.queries.PParameter;
import org.eclipse.incquery.runtime.matchers.psystem.queries.QueryInitializationException;
import org.eclipse.incquery.runtime.matchers.tuple.FlatTuple;
import org.eclipse.incquery.uml.derivedfeatures.RedefinableTemplateSignatureInheritedParameterMatch;
import org.eclipse.incquery.uml.derivedfeatures.RedefinableTemplateSignatureInheritedParameterMatcher;

/**
 * A pattern-specific query specification that can instantiate RedefinableTemplateSignatureInheritedParameterMatcher in a type-safe way.
 * 
 * @see RedefinableTemplateSignatureInheritedParameterMatcher
 * @see RedefinableTemplateSignatureInheritedParameterMatch
 * 
 */
@SuppressWarnings("all")
public final class RedefinableTemplateSignatureInheritedParameterQuerySpecification extends BaseGeneratedEMFQuerySpecification<RedefinableTemplateSignatureInheritedParameterMatcher> {
  private RedefinableTemplateSignatureInheritedParameterQuerySpecification() {
    super(GeneratedPQuery.INSTANCE);
  }
  
  /**
   * @return the singleton instance of the query specification
   * @throws IncQueryException if the pattern definition could not be loaded
   * 
   */
  public static RedefinableTemplateSignatureInheritedParameterQuerySpecification instance() throws IncQueryException {
    try{
    	return LazyHolder.INSTANCE;
    } catch (ExceptionInInitializerError err) {
    	throw processInitializerError(err);
    }
  }
  
  @Override
  protected RedefinableTemplateSignatureInheritedParameterMatcher instantiate(final IncQueryEngine engine) throws IncQueryException {
    return RedefinableTemplateSignatureInheritedParameterMatcher.on(engine);
  }
  
  @Override
  public RedefinableTemplateSignatureInheritedParameterMatch newEmptyMatch() {
    return RedefinableTemplateSignatureInheritedParameterMatch.newEmptyMatch();
  }
  
  @Override
  public RedefinableTemplateSignatureInheritedParameterMatch newMatch(final Object... parameters) {
    return RedefinableTemplateSignatureInheritedParameterMatch.newMatch((org.eclipse.uml2.uml.RedefinableTemplateSignature) parameters[0], (org.eclipse.uml2.uml.TemplateParameter) parameters[1]);
  }
  
  private static class LazyHolder {
    private final static RedefinableTemplateSignatureInheritedParameterQuerySpecification INSTANCE = make();
    
    public static RedefinableTemplateSignatureInheritedParameterQuerySpecification make() {
      return new RedefinableTemplateSignatureInheritedParameterQuerySpecification();					
    }
  }
  
  private static class GeneratedPQuery extends BaseGeneratedEMFPQuery {
    private final static RedefinableTemplateSignatureInheritedParameterQuerySpecification.GeneratedPQuery INSTANCE = new GeneratedPQuery();
    
    @Override
    public String getFullyQualifiedName() {
      return "org.eclipse.incquery.uml.derivedfeatures.redefinableTemplateSignatureInheritedParameter";
    }
    
    @Override
    public List<String> getParameterNames() {
      return Arrays.asList("source","target");
    }
    
    @Override
    public List<PParameter> getParameters() {
      return Arrays.asList(new PParameter("source", "org.eclipse.uml2.uml.RedefinableTemplateSignature"),new PParameter("target", "org.eclipse.uml2.uml.TemplateParameter"));
    }
    
    @Override
    public Set<PBody> doGetContainedBodies() throws QueryInitializationException {
      Set<PBody> bodies = Sets.newLinkedHashSet();
      try {
      {
      	PBody body = new PBody(this);
      	PVariable var_source = body.getOrCreateVariableByName("source");
      	PVariable var_target = body.getOrCreateVariableByName("target");
      	PVariable var__virtual_0_ = body.getOrCreateVariableByName(".virtual{0}");
      	PVariable var__virtual_1_ = body.getOrCreateVariableByName(".virtual{1}");
      	body.setExportedParameters(Arrays.<ExportedParameter>asList(
      		new ExportedParameter(body, var_source, "source"),
      				
      		new ExportedParameter(body, var_target, "target")
      	));
      	new TypeConstraint(body, new FlatTuple(var_source), new EClassTransitiveInstancesKey((EClass)getClassifierLiteral("http://www.eclipse.org/uml2/5.0.0/UML", "RedefinableTemplateSignature")));
      	new TypeConstraint(body, new FlatTuple(var_target), new EClassTransitiveInstancesKey((EClass)getClassifierLiteral("http://www.eclipse.org/uml2/5.0.0/UML", "TemplateParameter")));
      	new TypeConstraint(body, new FlatTuple(var_source), new EClassTransitiveInstancesKey((EClass)getClassifierLiteral("http://www.eclipse.org/uml2/5.0.0/UML", "RedefinableTemplateSignature")));
      	new TypeConstraint(body, new FlatTuple(var_source, var__virtual_0_), new EStructuralFeatureInstancesKey(getFeatureLiteral("http://www.eclipse.org/uml2/5.0.0/UML", "RedefinableTemplateSignature", "extendedSignature")));
      	new TypeConstraint(body, new FlatTuple(var__virtual_0_, var__virtual_1_), new EStructuralFeatureInstancesKey(getFeatureLiteral("http://www.eclipse.org/uml2/5.0.0/UML", "TemplateSignature", "parameter")));
      	new Equality(body, var__virtual_1_, var_target);
      	bodies.add(body);
      }
      	{
      	PAnnotation annotation = new PAnnotation("Surrogate");
      	annotation.addAttribute("feature", "inheritedParameter");
      	addAnnotation(annotation);
      }
      	// to silence compiler error
      	if (false) throw new IncQueryException("Never", "happens");
      } catch (IncQueryException ex) {
      	throw processDependencyException(ex);
      }
      return bodies;
    }
  }
}
